@@ -11,6 +11,7 @@ import subprocess
 from tabulate import tabulate
 from pathlib import Path
 from subprocess import Popen, PIPE
+from _version import __version__
 import datetime
 HOME = str(Path.home())
 CONFIG_FILE = "{0}/.cam.conf".format(HOME)
@@ -50,6 +51,7 @@ def bash(cmd):
 
 class CAM(object):
     def __init__(self):
+        self.__version__ = __version__
         if not os.path.exists(CONFIG_FILE):
             open(CONFIG_FILE, "w").write(DEFAULT_CONF)
         self._conf = yaml.load(open(CONFIG_FILE).read(), yaml.FullLoader) 
@@ -100,6 +102,7 @@ class CAM(object):
         """
         Start the server.
         """
+        log_info("Server: ", self._conf['server'], ":", str(self._conf['port']), ' v', self.__version__)
         port = self._conf["port"] if port is None else port
         os.system("redis-server --port {0} --requirepass {1}".format(port, self._conf["password"]))
 
@@ -113,6 +116,7 @@ class CAM(object):
         <br>Slurm node count\t: "bash('squeue').count('ltl-gpu')<4"
         <br>`cam worker "some start condition" prefix suffix` will add prefix and suffix to the command.
         """
+        log_info("Server: ", self._conf['server'], ":", str(self._conf['port']), ' v', self.__version__)
         log_info("Worker started. Listening to {0} ...".format(self._conf['server']))
         worker_start_time = get_time()
         self.worker_id = get_host()
@@ -175,8 +179,8 @@ class CAM(object):
         <br>`cam ls task 30` will list all tasks wile each column has at most 30 chars.
         """
         now = datetime.datetime.now()
+        log_info("Server: ", self._conf['server'], ":", str(self._conf['port']), ' v', self.__version__)
         if type is None or type == "task":
-            log_info("Server: ", self._conf['server'])
             pending = self._redis.lrange("pending", 0, -1)
             running = self._redis.lrange("running", 0, -1)
             res = pending + running
